@import url('https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600&display=swap');

*{
    margin: 0;
    padding: 0;
    box-sizing: border-box;
    font-family: 'Ubuntu';
}
body{
    min-height: 100vh;
    display: flex;
    align-items: center;
    justify-content: center;
    /* background-color: #ffffff; */
}
.container{
    max-width: 704px;
    width: 100%;
    height: 288px;
    background-color: #efefef;
    border-radius: 15px 15px 15px 15px;
    padding: 40px 0 ;
}
.center{
    margin: 0 40px;
    /* background-color: rgb(237, 94, 94); */
    border-radius: 15px 15px 15px 15px;
    display:flex;

}
.image{
    /* background-color: red; */
    border-radius: 15px;
    display: table-cell;
}
.profile-img{
    border-radius: 15px;
    width: 100%;
}
.content{
    /* display: flex;
    flex-direction: column; */
    /* padding: 0 7px; */
    display: table-cell;
    padding: 0 0 0 30px ;
}
.title{
    font-size: 27px;
    color: rgb(0, 0, 0);
    /* padding: 10px 5px 5px 30px ; */
}
mark.name {
    background-color: rgba(0, 0, 0, 0);
    color: rgb(107, 169, 103);
}
mark.post {
    background-color: black;
    color: white;
}
.description{
    font-size: 16px;
    color: rgb(0,0,0);
    text-align: justify;
    padding: 5px 0 5px 0;
    width: 403px;
    height: 70px;
    /* background-color: red; */
}
.button_1,
.button_2,
.button_3{
    border: none;
    font-size: 14px;
    color: #FFF;
    padding: 12px 0;
    background-color: #000000;
    border-radius: 15px;
    /* width: 110px; */
    /* margin: auto 130px 10px 0; */
    cursor: pointer;
    transition: all 0.3s ease;
}
.button_1{  
    width: 110px;
}
.button_2{
    width: 100px;
}
.button_3{
    width: 100px;
}


